﻿// get application
var app = angular.module("app");

// add controller
app.controller("appCtrl", function appCtrl($scope) {
  $scope.grid = null;
  var thePager = null;
  var pageSizeSelected = 0;
  // expose some data
  $scope.data = new wijmo.collections.CollectionView(getData(50), {
    groupDescriptions: ['country', 'product']
  });

  // update the coption of the Pager
  function updatePager(pager, current) {
    var caption = "Page " + (pager.pageIndex + 1) + " of " + pager.pageCount;
    document.getElementById(current).textContent = caption;
  }

  // add a footer row to the grid
  $scope.initGrid = function (s, e) {
    var grid = s;
    // assign variable 
    $scope.grid = s;
    thePager = new wijmo.grid.FlexGridPager(grid, 7);

    // add event listener for buttons
    // to move to different pages
    document.getElementById("the-pager").addEventListener("click", function (e) {
      var btn = wijmo.closest(e.target, "button");
      if (btn) {
        if (btn.id.indexOf("first") > -1) {
          thePager.moveToFirstPage();
        } else if (btn.id.indexOf("prev") > -1) {
          thePager.moveToPreviousPage();
        } else if (btn.id.indexOf("next") > -1) {
          thePager.moveToNextPage();
        } else if (btn.id.indexOf("last") > -1) {
          thePager.moveToLastPage();
        }
      }
    });

    var thePageSize = new wijmo.input.ComboBox('#the-page-size', {
      itemsSource: [10, 25, 50, 100],
      selectedItem: thePager.pageSize,
      selectedIndexChanged: function (s, e) {
        thePager.pageSize = s.selectedItem;
        // get pageSize selected 
        pageSizeSelected = s.selectedItem;
      }
    });

    thePager.stateChanged.addHandler(function (s, e) {
      // show the footer row only if last page
      grid.columnFooters.rows[0].visible = s.pageCount - 1 === s.pageIndex;
      updatePager(thePager, "the-pager-current");
    });

    updatePager(thePager, "the-pager-current");

    // create a GroupRow to show aggregates automatically
    var row = new wijmo.grid.GroupRow();
    row.visible = false;

    // add the new GroupRow to the grid's 'columnFooters' panel
    s.columnFooters.rows.push(row);

    // add a sigma to the header to show that this is a summary row
    s.bottomLeftCells.setCellData(0, 0, "\u03A3");
  };

  $scope.formatter = function (panel, r, c, cell) {
    var row = panel.rows[r],
      col = panel.columns[c];
    // if no aggregate, then no need to run the formatter
    if (col.aggregate === wijmo.Aggregate.None) {
      return;
    }
    // check if row is group footer row
    if (
      panel.cellType === wijmo.grid.CellType.Cell &&
      row instanceof wijmo.grid.GroupRow &&
      row.cssClass === "wj-groupfooter"
    ) {
      // find the parent group
      var group = findParentGroupRow(panel, row).dataItem;
      var d = wijmo.Globalize.format(
        group.getAggregate(col.aggregate, col.binding, row.collectionView),
        col.format
      );
      panel.setCellData(r, c, d, false, false);
      cell.innerHTML = d;
    }
  };

  // find the parent group row
  // by iterating over each row
  //before the current row
  function findParentGroupRow(panel, row) {
    var idx = row.index - 1;
    while (idx-- >= 0) {
      var currentRow = panel.rows[idx];
      if (
        currentRow instanceof wijmo.grid.GroupRow &&
        currentRow.level === row.level
      ) {
        // if found, then return the group created
        return currentRow;
      }
    }
  }


  // create some random data
  function getCountries() {
    return 'US,Canada,Mexico,Germany,UK,Sweden,Norway,Denmark,Japan,China,Korea'.split(',');
  }

  function getProducts() {
    return 'Phones,Cars,Skates,Shirts,Helmets'.split(',');
  }

  function getData(count) {
    var data = [],
      countries = getCountries(),
      products = getProducts();
    for (var i = 0; i < count; i++) {
      data.push({
        id: i,
        country: countries[i % countries.length],
        product: products[i % products.length],
        sales: Math.random() * 10000,
        expenses: Math.random() * 5000,
        discount: Math.round(Math.random() * 100) / 100,
        overdue: (i + 1) % 4 == 0
      });
    }
    return data;
  }

  // Export excel event use Save
  $scope.exportExcel = function () {
    try {
      thePager.pageSize = 0;

      var fileName = 'testGroupFooter.xlsx';
      wijmo.grid.xlsx.FlexGridXlsxConverter.save($scope.grid,
        {
          includeColumnHeaders: true,
          includeCellStyles: false,
        }, fileName);
    
      thePager.pageSize = pageSizeSelected;
    }
    catch (e) {
      console.log(e);

    }
  }

});



